==> cis-1.7.3.tar.gz: cis-1.7.3/README.md <==
CIS
===

[![Join the chat at https://gitter.im/cedadev/cis](https://badges.gitter.im/cedadev/cis.svg)](https://gitter.im/cedadev/cis?utm_source=badge&utm_medium=badge&utm_campaign=pr-badge&utm_content=badge)
[![Build Status](https://travis-ci.org/cedadev/cis.svg?branch=master)](https://travis-ci.org/cedadev/cis)
[![Documentation Status](https://readthedocs.org/projects/cis/badge/?version=latest)](https://readthedocs.org/projects/cis/?badge=latest)
[![Downloads](https://anaconda.org/conda-forge/cis/badges/downloads.svg)](https://anaconda.org/conda-forge/cis/files)

v1.4.0 DOI: [![DOI](https://zenodo.org/badge/doi/10.5281/zenodo.59939.svg)](http://dx.doi.org/10.5281/zenodo.59939)

CIS is an open source Python library and command-line tool for the easy collocation, visualization, analysis, and comparison of a
diverse set of gridded and ungridded datasets used across earth sciences. Visit our homepage at www.cistools.net.

For issue tracking and improvement suggestions please see our JIRA project at: https://jira.ceh.ac.uk/projects/JASCIS/issues.

Installation
------------

A pre-packaged version of CIS is available for installation using conda for Linux, Mac OSX and Windows.

Once conda is installed, you can easily install CIS with the following command:

    conda install -c conda-forge cis

If you don’t already have conda, you must first download and install it.
Anaconda is a free conda package that includes Python and many common scientific and data analysis libraries, and is available here: http://continuum.io/downloads.
Further documentation on using Anaconda and the features it provides can be found here: http://docs.continuum.io/anaconda/index.html

More details for installing CIS from source, and other package sources, can be found in the get-started [documentation](http://cistools.net/get-started#installation).


Contact
-------

Philip.Kershaw@stfc.ac.uk, Philip.Stier@physics.ox.ac.uk or Duncan.Watson-Parris@physics.ox.ac.uk


Copyright and licence
---------------------

(C) University of Oxford 2013

This file is part of the Community Intercomparison Suite (CIS).

CIS is free software: you can redistribute it and/or modify it under
the terms of the GNU Lesser General Public License as published by the
Free Software Foundation, either version 3 of the License, or
(at your option) any later version.

CIS is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU Lesser General Public License for more details.

You should have received a copy of the GNU Lesser General Public License
along with CIS.  If not, see <http://www.gnu.org/licenses/>.

We gratefully use a number of NASA Visible Earth 'Blue Marble' raster 
images in this repository.

==> cis-1.7.4.tar.gz: cis-1.7.4/README.md <==
CIS
===

[![Join the chat at https://gitter.im/cedadev/cis](https://badges.gitter.im/cedadev/cis.svg)](https://gitter.im/cedadev/cis?utm_source=badge&utm_medium=badge&utm_campaign=pr-badge&utm_content=badge)
[![Build Status](https://circleci.com/gh/cedadev/cis/tree/master.svg?style=svg)](https://circleci.com/gh/cedadev/cis/tree/master)
[![codecov](https://codecov.io/gh/cedadev/cis/branch/master/graph/badge.svg?token=8QTY6ZZN95)](https://codecov.io/gh/cedadev/cis)
[![Documentation Status](https://readthedocs.org/projects/cis/badge/?version=latest)](https://readthedocs.org/projects/cis/?badge=latest)
[![Downloads](https://anaconda.org/conda-forge/cis/badges/downloads.svg)](https://anaconda.org/conda-forge/cis/files)
[![DOI](https://zenodo.org/badge/DOI/10.5281/zenodo.4518867.svg)](https://doi.org/10.5281/zenodo.4518867)


CIS is an open source Python library and command-line tool for the easy collocation, visualization, analysis, and comparison of a
diverse set of gridded and ungridded datasets used across earth sciences. Visit our homepage at www.cistools.net.

For issue tracking and improvement suggestions please see our JIRA project at: https://jira.ceh.ac.uk/projects/JASCIS/issues.

Installation
------------

A pre-packaged version of CIS is available for installation using conda for Linux, Mac OSX and Windows.

Once conda is installed, you can easily install CIS with the following command:

    conda install -c conda-forge cis

If you don’t already have conda, you must first download and install it.
Anaconda is a free conda package that includes Python and many common scientific and data analysis libraries, and is available here: http://continuum.io/downloads.
Further documentation on using Anaconda and the features it provides can be found here: http://docs.continuum.io/anaconda/index.html

More details for installing CIS from source, and other package sources, can be found in the get-started [documentation](http://cistools.net/get-started#installation).


Contact
-------

Philip.Kershaw@stfc.ac.uk, Philip.Stier@physics.ox.ac.uk or Duncan.Watson-Parris@physics.ox.ac.uk


Copyright and licence
---------------------

(C) University of Oxford 2013

This file is part of the Community Intercomparison Suite (CIS).

CIS is free software: you can redistribute it and/or modify it under
the terms of the GNU Lesser General Public License as published by the
Free Software Foundation, either version 3 of the License, or
(at your option) any later version.

CIS is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU Lesser General Public License for more details.

You should have received a copy of the GNU Lesser General Public License
along with CIS.  If not, see <http://www.gnu.org/licenses/>.

We gratefully use a number of NASA Visible Earth 'Blue Marble' raster 
images in this repository.
